@@ -52,6 +52,7 @@ our @EXPORT_OK = qw/
 	get_unknown_chunks
 	get_valid
 	init_io
+	init_io_x
 	libpng_supports
 	permit_mng_features
 	read_end
@@ -67,6 +68,8 @@ our @EXPORT_OK = qw/
 	set_add_alpha
 	set_alpha_mode
 	set_bKGD
+	set_back
+	set_background
 	set_bgr
 	set_cHRM
 	set_cHRM_XYZ
@@ -136,6 +139,8 @@ our @EXPORT_OK = qw/
 	write_to_scalar
 	color_type_name
 	copy_png
+	create_reader
+	create_writer
 	get_internals
 	image_data_diff
 	png_compare
@@ -149,7 +154,7 @@ our %EXPORT_TAGS = (
 );
 
 require XSLoader;
-our $VERSION = '0.52_03';
+our $VERSION = '0.52_04';
 
 XSLoader::load('Image::PNG::Libpng', $VERSION);
 
@@ -400,6 +405,24 @@ sub png_compare
     return 0;
 }
 
+sub create_reader
+{
+    my ($file) = @_;
+    open my $in, "<:raw", $file or croak "Can't open '$file': $!";
+    my $png = create_read_struct ();
+    $png->init_io ($in);
+    return $png;
+}
+
+sub create_writer
+{
+    my ($file) = @_;
+    open my $in, ">:raw", $file or croak "Can't open '$file': $!";
+    my $png = create_write_struct ();
+    $png->init_io ($in);
+    return $png;
+}
+
 1;
 
 # Local Variables:
